library(data.table)
library(here)
library(ggplot2)
library(grid)
library(readxl)
library(magrittr)

text.size = 10
dir = here()
setwd(dir)

# population

  # 1. hsus
  setwd(dir)
  setwd("../data/hsus")
  hsus = read_xls("Aa6-8.xls") %>% data.table()
  year = hsus[,1] %>% unlist() %>%  as.numeric()
  pop = hsus[,3] %>% unlist() %>%  as.numeric()
  hsus = data.table(year, pop) %>% na.omit()
  hsus = hsus[year < 1960]
  
  # 2. world bank
  setwd(dir)
  setwd("../data/world_bank")
  wdi = fread("wdi.csv")
  wdi = wdi[country.code == "USA"]
  wdi = data.table(year = wdi$year, pop = wdi$SP.POP.TOTL/1000) %>% na.omit()

  # 3. splice
  pop = rbind(hsus, wdi)
  
# electricity
  
  # 1. hsus
  setwd(dir)
  setwd("../data/hsus")
  hsus = read_xls("Db228-233.xls") %>% data.table()
  year = hsus[,1] %>% unlist() %>%  as.numeric()
  elec = hsus[,2] %>% unlist() %>%  as.numeric()
  hsus = data.table(year, elec) %>% na.omit()

  # 2. eia
  setwd(dir)
  setwd("../data/eia/electricity_use")
  eia = fread("electricity_annual.csv")
  eia = data.table(year = eia$year, elec = eia$Value) %>% na.omit()

  # 3. splice hsus to eia in 1949
  index = eia$elec[eia$year == 1949] / hsus$elec[hsus$year == 1949]
  hsus$elec = hsus$elec*index  
  hsus = hsus[year < 1949]
  elec = rbind(hsus, eia)

# electricity per capita (mwh per person per year)
  elec = merge(elec, pop, by = "year")
  elec$elec_pc = elec$elec / elec$pop * 10^6 / 1000 / 1000


# plant size
  setwd(dir)
  setwd("../data/eia/form_860")
  plant = fread("plant_mean_capacity.csv")

# merge all
  all = merge(elec, plant, by = "year")
  
  # index
  all$elec_index = all$elec_pc / all$elec_pc[1]
  all$capacity_index = all$mean_capacity / all$mean_capacity[1]

# plot
elec_plot = ggplot(data = all) +
  geom_line(aes(x = year, y = elec_index), col = "dodgerblue4", size = 1) +
  geom_line(aes(x = year, y = capacity_index), col = "red", size = 1) +  
  geom_point(aes(x = 1902, y = 1), size = 2) +
  scale_x_continuous("Year", breaks = seq(1900, 2040, 20)) +
  scale_y_log10("Indexed growth (1902 = 1)", breaks = c(1, 2, 5, 10, 20, 50, 100, 200)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x=element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y=element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", label = "US electricity\nuse per capita",
           x = 1955, y = 150, size = 3, family = "Times") +
  annotate("text", label = "Average size\nof US power plant\n(nameplate capacity)",
           x = 1995, y = 40, size = 3, family = "Times")


# inset plot

  # regression 
  r = lm(log(all$elec_pc) ~ log(all$mean_capacity))
  r2 = summary(r)$r.squared
  r2 = paste("R^2==", round(r2, 2)) 
  slope = coef(r)[2]
  
  
inset = ggplot(data = all) +
  geom_smooth(aes(x = elec_pc, y = mean_capacity), method = "lm", 
               col = "black", size = 0.2, fill = NA, linetype = 2) +
  geom_path(aes(x = elec_pc, y = mean_capacity), col = "dodgerblue4", size = 0.8) +
  scale_x_log10("Electricity use per capita (MWH)") +
  scale_y_log10("Average plant capacity (MW)", breaks = c(1, 2, 5, 10, 20, 50, 100, 200)) +
  ggtitle("Correlation") +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5),
        axis.line = element_line(color = "black"), 
        axis.title.x=element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y=element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size*0.7, family="Times")) +
  annotate("text", label = r2, parse = T, x = 0.2, y = 100, size = 2, family = "Times")

inset_grob = ggplotGrob(inset)
elec_plot = elec_plot + annotation_custom(inset_grob, xmin = 1960, xmax = 2022, ymin = -0.05, ymax = 1.15)



# export
setwd(dir)
gA = ggplotGrob(elec_plot)

png("electricity_plant_size.png", width = 5, height = 5, res = 600, units = "in")
grid.draw(gA)
dev.off()

  
  
  
  