library(hmod)
library(ineq)
library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)

dir = here()
text.size = 10

# steep hierarchy
h1 = hierarchy(10^5, 2)
hp1 = hierarchical_power(h1)
dist_1 = rep(hp1, h1)
g1 = gini(dist_1)
lc1 = Lc(dist_1)
lc1 = data.table(p = lc1$p, l =  lc1$L, g = g1, s = "span of control = 2")

# flat hierarchy
h2 = hierarchy(10^5, 500)
hp2 = hierarchical_power(h2)
dist_2 = rep(hp2, h2)
g2 = gini(dist_2)
lc2 = Lc(dist_2)
lc2 = data.table(p = lc2$p, l =  lc2$L, g = g2, s = "span of control = 500")

# medium hierarchy
h3 = hierarchy(10^5, 10)
hp3 = hierarchical_power(h3)
dist_3 = rep(hp3, h3)
g3 = gini(dist_3)
lc3 = Lc(dist_3)
lc3 = data.table(p = lc3$p, l =  lc3$L, g = g3, s = "span of control = 10")

# merge
model = rbind(lc1, lc2, lc3)
model$p = model$p*100
model$l = model$l*100

model$s = as.factor(model$s)
model$s = reorder(model$s, -model$g, FUN = median)


lc_equal = data.table(p = 0:1, l = 0:1)*100

# plot
lplot = ggplot() + 
  geom_line(data = lc_equal, aes(x = p, y = l)) +
  geom_line(data = model, aes(x = p, y = l, col = s), size = 0.8) +
  scale_x_continuous("Hierarchical power percentile", breaks = seq(0, 100, 10)) +
  scale_y_continuous("Share of hierarchical power (%)", breaks = seq(0, 100, 10)) +
  ggtitle("A.  How the span of control affects the distribution of hierarchical power") +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x=element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y=element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", label = "Perfect\nequality", 
           x = 50, y = 62, size = 3, family = "Times") +
  annotate("text", label = "A hierarchy with\n100,000 members", 
           x = 84, y = 60, size = 3, family = "Times") 


# effect of span of control
#################################################
firm_size = 10^5
span_vec = exp(seq(log(1.5), log(1000), length.out = 1000))
g = rep(NA, length(firm_size))

for(i in 1:length(span_vec)){
  
  s = span_vec[i]
  h = hierarchy(firm_size, s)
  hp = hierarchical_power(h)
  dist = rep(hp, h)
  g[i] = gini(dist)
  
}

model = data.table(s = span_vec, g)

# empirical range
# us military
setwd(dir)
setwd("../data/military")
military = fread("military_rank_pay.csv")

# case studies
setwd(dir)
setwd("../data/firm_case_studies")
case_study = fread("case_subordinates.csv")[,-1:-9]


# plot
span_plot = ggplot() + 
  geom_hline(yintercept = 0.5, col ="grey", linetype = 2) +
  geom_vline(xintercept = 150, col = "red", linetype = 2) +
  geom_line(data = model, aes(x = s, y = g), size = 0.8, col = "dodgerblue4") +
  scale_x_log10("Span of control", breaks = c(1, 2, 5, 10, 20, 50, 100, 200, 500, 1000)) +
  scale_y_continuous("Concentration of hierarchical power (Gini index)") +
  coord_cartesian(ylim = c(0.4, 0.9)) +
  ggtitle("B.  How the span of control affects the concentration of hierarchical power") +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x=element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y=element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", label = "Minimum Gini index", 
           x = 10, y = 0.52, size = 3, family = "Times") +
  annotate("text", label = "A hierarchy with\n100,000 members", 
           x = 10, y = 0.7, size = 3, family = "Times") +
  annotate("text", label = "Dunbar's\nnumber", hjust = 0,
           x = 162, y = 0.8, size = 3, family = "Times") 



# export
setwd(dir)
gA = ggplotGrob(lplot)
gB = ggplotGrob(span_plot)

png("hierarchy_properties_span.png", width = 5, height = 8, res = 600, units = "in")
grid.arrange(rbind(gA, gB))
dev.off()


