library(hmod)
library(ineq)
library(magrittr)
library(data.table)
library(ggplot2)
library(gridExtra)
library(here)

dir = here()
text.size = 10

# model
#----------------------------------------------
firm_size = 10^5
span_vec = exp(seq(log(1.02), log(1000), length.out = 1000))
g = rep(NA, length(firm_size))

for(i in 1:length(span_vec)){
  
  s = span_vec[i]
  h = hierarchy(firm_size, s)
  hp = hierarchical_power(h)
  dist = rep(hp, h)
  g[i] = gini(dist)
  
}

model = data.table(s = span_vec, g)

# empirical span
setwd(dir)
setwd("../synthesis/span")
span = fread("span.csv")
emp_max= max(span$span)
lab_center = exp(mean(c(0, log(emp_max))))

# plot
mod_plot = ggplot() + 
  geom_rect(aes(xmin = 1, xmax = emp_max, ymin = 0, ymax = 2), fill = "red", alpha = 0.1) +
  geom_hline(yintercept = 0.5, col ="grey", linetype = 2) +
  geom_vline(xintercept = 150, col = "red", linetype = 2) +
  geom_line(data = model, aes(x = s, y = g), size = 0.8, col = "dodgerblue4") +
  scale_x_log10("Span of control", breaks = c(1, 2, 5, 10, 20, 50, 100, 200, 500, 1000)) +
  scale_y_continuous("Concentration of hierarchical power (Gini index)") +
  coord_cartesian(ylim = c(0.4, 0.9)) +
  theme_bw() +
  theme(panel.border = element_rect(colour = "black"),
        panel.grid.major = element_blank(), 
        panel.grid.minor = element_blank(), 
        legend.position = c(0.2, 0.85),
        legend.title = element_blank(),
        legend.text = element_text(size = rel(0.8)),
        plot.title = element_text(face="bold", hjust = 0.5, size = rel(1)),
        axis.line = element_line(color = "black"), 
        axis.title.x = element_text(vjust=-0.3, size=rel(0.9)),
        axis.title.y = element_text(vjust= 1.1, size=rel(0.9)),
        axis.text.x = element_text(margin=margin(5,5,0,0,"pt")),
        axis.text.y = element_text(margin=margin(3,5,0,3,"pt")),
        axis.ticks.length = unit(-0.7, "mm"),
        text=element_text(size = text.size, family="Times")) +
  annotate("text", label = "A hierarchy with\n100,000 members", 
           x = 15, y = 0.85, size = 3, family = "Times") +
  annotate("text", label = "Minimum\nGini index", 
           x = 600, y = 0.53, size = 2.5, family = "Times") +
  annotate("text", label = "Dunbar's\nnumber", hjust = 0,
           x = 162, y = 0.85, size = 2.5, family = "Times") +
  annotate("text", label = "span of control\nempirical range", hjust = 0.5,
           x = lab_center , y = 0.55, size = 2.5, family = "Times") +
  geom_segment(aes(x = lab_center/2, y = 0.55, xend = 1, yend = 0.55),  
               arrow=arrow(type="closed", length=unit(0.1,"cm"))) +
  geom_segment(aes(x = lab_center*2, y = 0.55, xend = emp_max, yend = 0.55),  
               arrow=arrow(type="closed", length=unit(0.1,"cm"))) 



# export
setwd(dir)
gA = ggplotGrob(mod_plot)

png("span_effect.png", width = 5, height = 4.5, res = 600, units = "in")
grid.arrange(gA)
dev.off()


